#
# spec file for package python-pysmi
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} > 1500
%bcond_without libalternatives
%else
%bcond_with libalternatives
%endif

%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
Name:           python-pysmi%{psuffix}
Version:        0.3.4
Release:        4.2
Summary:        SNMP SMI/MIB Parser
License:        BSD-2-Clause
URL:            http://pysmi.sourceforge.net/
Source:         https://files.pythonhosted.org/packages/source/p/pysmi/pysmi-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module ply}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros >= 20210929
%if %{with test}
BuildRequires:  %{python_module pysnmp}
BuildRequires:  %{python_module pytest}
%endif
Requires:       python-ply
%if %{with libalternatives}
BuildRequires:  alts
Requires:       alts
%else
Requires(post): update-alternatives
Requires(postun): update-alternatives
%endif
BuildArch:      noarch
%python_subpackages

%description
A pure-Python implementation of SNMP/SMI MIB parsing and conversion library.
Can produce PySNMP MIB modules.

Documentation: http://pysmi.sf.net

%prep
%setup -q -n pysmi-%{version}

%build
%pyproject_wheel

%install
%if !%{with test}
%pyproject_install
mv %{buildroot}%{_bindir}/mibdump.py %{buildroot}%{_bindir}/mibdump
mv %{buildroot}%{_bindir}/mibcopy.py %{buildroot}%{_bindir}/mibcopy
%python_clone -a %{buildroot}%{_bindir}/mibdump
%python_clone -a %{buildroot}%{_bindir}/mibcopy
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}
%pytest
%endif

%if !%{with test}
%pre
# If libalternatives is used: Removing old update-alternatives entries.
%python_libalternatives_reset_alternative mibdump

%post
%python_install_alternative mibdump

%postun
%python_uninstall_alternative mibdump

%files %{python_files}
%license LICENSE.rst
%doc README.md CHANGES.rst
%{python_sitelib}/pysmi
%{python_sitelib}/pysmi-%{version}.dist-info
%python_alternative %{_bindir}/mibdump
%python_alternative %{_bindir}/mibcopy
%endif

%changelog
* Mon Feb 19 2024 Steve Kowalik <steven.kowalik@suse.com>
- Switch to pyproject macros.
- Use pytest for the testsuite.
- No more greedy globs in %%files.
* Wed Oct  6 2021 Matej Cepl <mcepl@suse.com>
- Add multibuild to separate test phase from the build one.
* Tue Oct  5 2021 Stefan Schubert <schubi@suse.de>
- Added BuildRequires:  alts
* Thu Sep 30 2021 Stefan Schubert <schubi@suse.de>
- Use libalternatives instead of update-alternatives.
* Mon Oct 14 2019 Matej Cepl <mcepl@suse.com>
- Replace %%fdupes -s with plain %%fdupes; hardlinks are better.
* Mon May  6 2019 pgajdos@suse.com
- version update to 0.3.4
  - Rebased MIB importing code onto `importlib` because `imp` is long
    deprecated
  - Fixed Py file borrower to become functional
* Thu Jan 10 2019 mardnh@gmx.de
- Update to version 0.3.3
  * Exit code indication of the command-line tools aligned with
    sysexits.h to report more useful termination status
- Update to version 0.3.2
  * Fixed compiler crash when building comments at a platform
    which has broken users/groups databases
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Fri Aug 11 2017 tbechtold@suse.com
- update to 0.3.1:
  * INET-ADDRESS-MIB configured as pre-built at pysnmp codegen
  * JSON codegen produces "nodetype" element for OBJECT-TYPE
  * Fix to mibdump.py --destination-directory option
  * Fix to pysnmp and JSON code generators to properly refer to MIB module
  defining particular MIB object
  * The @mib@ magic in reader's URL template made optional. If it is not present,
  MIB module name is just appended to URL template
  * Send User-Agent containing pysmi and Python versions as well as platform name.
  * Fixed missing STATUS/DISPLAY-HINT/REFERENCE/etc fields generation at pysnmp
  backend when running in the non-full-text mode
  * Fixed broken `ordereddict` dependency on Python 2.6-
  * Generate REFERENCE and STATUS fields at various SMI objects
  * Generate DESCRIPTION field followed REVISION field at MODULE-IDENTITY objects
  * Generate PRODUCT-RELEASE field at AGENT-CAPABILITIES objects
  * Generated Python source aligned with PEP8
  * MIB texts cleaned up by default, --keep-texts-layout preserves original formatting
  * Fix to the `ordereddict` conditional dependency
  * Missing test module recovered
  * Failing tests fixed
  * JSON code generating backend implemented
  * Experimental JSON OID->MIB indices generation implemented
  * Package structure flattened for easier use
  * Minor refactoring to the test suite
  * Source code statically analyzed, hardened and PEP8-ized
  * Files closed explicitly to mute ResourceWarnings
  * Fixed to Python 2.4 (and aged ply) compatibility
  * Added a workaround to avoid generating pysnmp TextualConvention classes
  inheriting from TextualConvention (when MIB defines a TEXTUAL-CONVENTION
  based on another TEXTUAL-CONVENTION as SYNTAX)
  * Author's e-mail changed, copyright extended to year 2017
- convert to singlespec
* Mon Aug  1 2016 mardnh@gmx.de
- Update to version 0.0.07
  * Crash on existing .py file handling fixed.
  * Fix to __doc__ use in setup.py to make -O0 installation mode working.
  * Fix to PyPackageSearcher not to fail on broken Python packages.
  * Source code pep8'ed
  * Copyright added to source files.
* Sat Nov 21 2015 bwiedemann@suse.com
- initial package of version 0.0.6
